summaryrefslogtreecommitdiffstats
path: root/src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java')
-rw-r--r--src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java9
1 files changed, 4 insertions, 5 deletions
diff --git a/src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java b/src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java
index 03ef552..9fa329d 100644
--- a/src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java
+++ b/src/demos/proceduralTexturePhysics/ProceduralTexturePhysics.java
@@ -48,11 +48,11 @@ import gleem.linalg.*;
*
* <P>
*
* Demonstrates pbuffers, vertex programs, register combiners
*
* <P>
*
* Ported to Java by Kenneth Russell
*
*/
@@ -131,9 +131,8 @@ public class ProceduralTexturePhysics {
try {
checkExtension(gl, "GL_ARB_multitexture");
- checkExtension(gl, "GL_NV_vertex_program");
- checkExtension(gl, "GL_NV_texture_shader");
- checkExtension(gl, "GL_NV_register_combiners");
+ checkExtension(gl, "GL_ARB_vertex_program");
+ checkExtension(gl, "GL_ARB_fragment_program");
checkExtension(gl, "GL_ARB_pbuffer");
checkExtension(gl, "GL_ARB_pixel_format");
} catch (GLException e) {
@@ -48,11 +48,11 @@ import gleem.linalg.*;
* <P>
*
- * Demonstrates pbuffers, vertex programs, register combiners
+ * Demonstrates pbuffers, vertex programs, fragment programs
*
* <P>
@@ -48,11 +48,11 @@ import gleem.linalg.*;
* <P>
*
- * Ported to Java by Kenneth Russell
+ * Ported to Java and ARB_fragment_program by Kenneth Russell
*
*/